@@ -4,18 +4,28 @@ Model for a Zwave Node's device class.
 https://zwave-js.github.io/node-zwave-js/#/api/node?id=deviceclass
 """
 
-from typing import List, Optional
+from typing import List, Optional, TypedDict
+
+
+class DeviceClassDataType(TypedDict):
+    """Represent a device class data dict type."""
+
+    basic: str
+    generic: str
+    specific: str
+    mandatorySupportedCCs: List[str]
+    mandatoryControlCCs: List[str]
 
 
 class DeviceClass:
     """Model for a Zwave Node's device class."""
 
-    def __init__(self, data: dict) -> None:
+    def __init__(self, data: DeviceClassDataType) -> None:
         """Initialize."""
         self.data = data
 
     @property
-    def basic(self) -> Optional[str]:
+    def basic(self) -> Optional[str]:  # TODO: Is this really optional?
         """Return basic property."""
         return self.data.get("basic")
 
